From f4be573dcc84425e4002e9a5055654dda6ea2cfb Mon Sep 17 00:00:00 2001
From: Wang Ziming <wangziming@huawei.com>
Date: Thu, 7 May 2020 12:01:52 +0800
Subject: [PATCH 64/77] libvirt_mem: edit cpu_model and hugepages page_size to
 adapt to aarch64 and x86_64 platform.

As cpu_model and hugepages page_size is different in arrch64 and x86_64
platform, we should adapt to both of them.

Signed-off-by: Wang Ziming <wangziming@huawei.com>
---
 libvirt/tests/cfg/libvirt_mem.cfg | 19 ++++++++++++-------
 libvirt/tests/src/libvirt_mem.py  |  5 ++++-
 2 files changed, 16 insertions(+), 8 deletions(-)

diff --git a/libvirt/tests/cfg/libvirt_mem.cfg b/libvirt/tests/cfg/libvirt_mem.cfg
index 70a78212..ae783e03 100644
--- a/libvirt/tests/cfg/libvirt_mem.cfg
+++ b/libvirt/tests/cfg/libvirt_mem.cfg
@@ -11,12 +11,12 @@
     vcpu = 4
     variants:
         - positive_test:
-            max_mem_rt = 2560000
-            max_mem = 1024000
-            current_mem = 1024000
-            numa_cells = "{'id':'0','cpus':'0-1','memory':'512000','unit':'KiB'} {'id':'1','cpus':'2-3','memory':'512000','unit':'KiB'}"
+            max_mem_rt = 4194304
+            max_mem = 2097152
+            current_mem = 2097152
+            numa_cells = "{'id':'0','cpus':'0-1','memory':'1048576','unit':'KiB'} {'id':'1','cpus':'2-3','memory':'1048576','unit':'KiB'}"
             add_mem_device = "yes"
-            tg_size = 524288
+            tg_size = 1048576
             tg_sizeunit = "KiB"
             tg_node = 0
             test_qemu_cmd = "yes"
@@ -47,8 +47,8 @@
                         - default:
                         - max_slots:
                             max_mem_rt = 138412032
-                            max_mem_slots = 256
-                            attach_times = 256
+                            max_mem_slots = 58
+                            attach_times = 58
                             variants:
                                 - without_reboot:
                                 # Do not enable hot_reboot until unless it has to be tested.
@@ -96,6 +96,11 @@
                     page_unit = "KiB"
                     node_mask = 0
                     huge_pages = "{'size':'2048','unit':'KiB','nodeset':'0'}"
+                    aarch64:
+                        cpu_mode = "host-passthrough"
+                        page_size = 524288
+                        tg_size = 1048576
+                        huge_pages = "{'size':'524288','unit':'KiB','nodeset':'0'}"
                     hugepage_force_allocate = "yes"
                     variants:
                         - hot_plug:
diff --git a/libvirt/tests/src/libvirt_mem.py b/libvirt/tests/src/libvirt_mem.py
index 1f04b264..a6b5d060 100644
--- a/libvirt/tests/src/libvirt_mem.py
+++ b/libvirt/tests/src/libvirt_mem.py
@@ -336,7 +336,10 @@ def run(test, params, env):
                     cells[cell]["memory"] = memory_value
             cpu_xml = vm_xml.VMCPUXML()
             cpu_xml.xml = "<cpu><numa/></cpu>"
-            cpu_mode = params.get("cpu_mode")
+            if platform.machine().lower() == "aarch64":
+                cpu_mode = params.get("cpu_mode", "host-passthrough")
+            else:
+                cpu_mode = params.get("cpu_mode")
             model_fallback = params.get("model_fallback")
             if cpu_mode:
                 cpu_xml.mode = cpu_mode
-- 
2.23.0

